@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from pydantic.dataclasses import dataclass
 
 from magnumapi.cadata.Definition import Definition
 
@@ -14,7 +14,6 @@ class CableDefinition(Definition):
            n_s (int): The number of strands (mm).
            l_tp (float): The length of the transposition pitch (mm) of the Rutherford-type cable.
            f_degrad (float): The degradation of the critical current density in %.
-           type (str): The cable type (e.g., Rutherford cable, HTS tape).
     """
     width: float
     thickness_i: float
@@ -22,7 +21,6 @@ class CableDefinition(Definition):
     n_s: int
     l_tp: float
     f_degrad: float
-    type: str = ""
 
     @staticmethod
     def get_magnum_to_roxie_dct() -> dict:
@@ -33,5 +31,4 @@ class CableDefinition(Definition):
                 "n_s": "ns",
                 "l_tp": "transp.",
                 "f_degrad": "degrd",
-                "comment": "Comment",
-                "type": None}
+                "comment": "Comment"}
