@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from pydantic.dataclasses import dataclass
 
 from magnumapi.cadata.Definition import Definition
 
@@ -21,7 +21,7 @@ class RemFitDefinition(Definition):
            c10 (float): fit coefficient 10.
            c11 (float): fit coefficient 11.
     """
-    type: str = ''
+    type: int = None
     c1: float = 0.0
     c2: float = 0.0
     c3: float = 0.0
