@@ -6,6 +6,7 @@ from itertools import chain
 
 import pandas as pd
 
+import magnumapi
 from magnumapi.geometry.GeometryPlot import GeometryPlot
 from magnumapi.geometry.blocks.RectangularBlock import RectangularBlock
 from magnumapi.geometry.primitives.Line import Line
@@ -18,7 +19,7 @@ from magnumapi.geometry.blocks.CosThetaBlock import RelativeCosThetaBlock, Homog
     AbsoluteCosThetaBlock
 
 print('Analysis executed on %s' % str(datetime.datetime.now()).split('.')[0])
-print('Loaded MagNum API version 0.0.1')
+print('Loaded MagNum API version %s' % magnumapi.__version__)
 
 
 class Geometry(ABC):
