@@ -6,12 +6,54 @@ from magnumapi.geometry.SlottedGeometry import SlottedRelativeCosThetaGeometry
 from magnumapi.geometry.blocks.Block import Block
 from magnumapi.geometry.blocks.CosThetaBlock import AbsoluteCosThetaBlock
 from magnumapi.geometry.primitives.Line import Line
+from magnumapi.optimization.design_variable.Individual import Individual
 
 
 class GeometryChange:
 
+    @staticmethod
+    def update_global_variables(geometry, individual: Individual) -> Geometry:
+        geometry = deepcopy(geometry)
+        for global_dv in individual.get_global_dvs():
+            if hasattr(geometry, global_dv.variable):
+                setattr(geometry, global_dv.variable, global_dv.value)
+
+        return geometry
+
     @classmethod
-    def limit_minimum_phi_r(cls, geometry, min_length=1):
+    def update_layer_variables(cls, geometry, individual: Individual) -> Geometry:
+        geometry = deepcopy(geometry)
+        for layer_dv in individual.get_layer_dvs():
+            layer_def = geometry.layer_defs[layer_dv.layer - 1]
+            if hasattr(layer_def, layer_dv.variable):
+                setattr(layer_def, layer_dv.variable, layer_dv.value)
+        return geometry
+
+    @classmethod
+    def update_block_variables(cls, geometry, individual: Individual) -> Geometry:
+        geometry = deepcopy(geometry)
+        for block_dv in individual.get_block_dvs():
+            cls.update_block_variable(geometry, block_dv, block_dv.block)
+        return geometry
+
+    @classmethod
+    def update_block_variable(cls, geometry, dv, block):
+        block_index = geometry.layer_defs[dv.layer - 1].blocks[block - 1]
+        index_in_blocks = geometry.get_index_in_blocks_for_layer_block_index(block_index)
+        block_def = geometry.blocks[index_in_blocks].block_def
+        if hasattr(block_def, dv.variable):
+            setattr(block_def, dv.variable, dv.value)
+
+    @classmethod
+    def update_multiblock_variables(cls, geometry, individual: Individual) -> Geometry:
+        geometry = deepcopy(geometry)
+        for multiblock_dv in individual.get_multiblock_dvs():
+            for index in range(multiblock_dv.block_start, multiblock_dv.block_end):
+                cls.update_block_variable(geometry, multiblock_dv, index)
+        return geometry
+
+    @classmethod
+    def limit_minimum_phi_r(cls, geometry, min_length=1) -> Geometry:
         geometry = deepcopy(geometry)
         for layer_def in geometry.layer_defs:
             for blocks_index, block_index in enumerate(layer_def.blocks):
@@ -24,38 +66,30 @@ class GeometryChange:
 
         return geometry
 
-
     @classmethod
-    def update_spar_thickness(cls, geometry: SlottedRelativeCosThetaGeometry, decoded):
+    def update_nco_varying_blocks(cls,
+                                  geometry,
+                                  individual: Individual) -> SlottedRelativeCosThetaGeometry:
         geometry = deepcopy(geometry)
 
-        for layer_index, layer_def in enumerate(geometry.layer_defs):
-            layer_def.spar_thickness = decoded.get('spar_thickness:%d:' % (layer_index + 1), layer_def.spar_thickness)
-
-        # ToDo: here one should use a builder!!!
-        return SlottedRelativeCosThetaGeometry(r_aperture=geometry.r_aperture,
-                                               blocks=geometry.blocks,
-                                               layer_defs=geometry.layer_defs)
-
-    @classmethod
-    def update_nco_varying_blocks(cls, geometry, decoded):
-        geometry = deepcopy(geometry)
+        nco_dvs = [dv for dv in individual.get_block_dvs() if dv.variable == 'nco']
         block_index = 1
         blocks = []
         # for each layer
-        for layer_index, layer_def in enumerate(geometry.layer_defs):
+        for layer_index, layer_def in enumerate(geometry.layer_defs, start=1):
             # find a reference block - first block in layer_def
             block_layer_index_ref = layer_def.blocks[0]
             block_index_ref = geometry.get_index_in_blocks_for_layer_block_index(block_layer_index_ref)
+            block_def_ref = geometry.blocks[block_index_ref]
 
             # find all ncos that belong to that layer and are non-zero
-            nco_values = {key: value for key, value in decoded.items() if value and 'nco:%d' % (layer_index + 1) in key}
-
             # update a copy of the reference block as long as there are non-zero blocks - todo: sort the keys
             layer_blocks = []
-            for key, value in nco_values.items():
-                block_def_ref = deepcopy(geometry.blocks[block_index_ref])
-                block_def_ref.block_def.nco = value
+
+            nco_layer_dvs = [dv for dv in nco_dvs if (dv.value > 0) and (dv.layer == layer_index)]
+            for nco_layer_dv in nco_layer_dvs:
+                block_def_ref = deepcopy(block_def_ref)
+                block_def_ref.block_def.nco = nco_layer_dv.value
                 block_def_ref.block_def.no = block_index
                 layer_blocks.append(block_index)
                 block_index += 1
@@ -68,36 +102,30 @@ class GeometryChange:
                                                layer_defs=geometry.layer_defs)
 
     @classmethod
-    def update_alpha_radial(cls, geometry, chromosome):
+    def update_alpha_radial(cls, geometry, individual: Individual):
         geometry = deepcopy(geometry)
-        for block_index_variable, value in chromosome.items():
-            if 'alpha_rad_r' in block_index_variable:
-                variable, layer_index, block_layer_index = block_index_variable.split(':')
-                layer_index = int(layer_index)
-                block_layer_index = int(block_layer_index)
+        alpha_r_dvs = [block_dv for block_dv in individual.get_block_dvs() if block_dv.variable == 'alpha_rad_r']
+        for alpha_r_dv in alpha_r_dvs:
 
-                # block index
-                if block_layer_index <= len(geometry.layer_defs[layer_index - 1].blocks):
-                    no_block = geometry.layer_defs[layer_index - 1].blocks[block_layer_index - 1]
-                    block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
-                    geometry.blocks[block_index].block_def.alpha_r += value
+            # block index
+            if alpha_r_dv.block <= len(geometry.layer_defs[alpha_r_dv.layer - 1].blocks):
+                no_block = geometry.layer_defs[alpha_r_dv.layer - 1].blocks[alpha_r_dv.block - 1]
+                block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
+                geometry.blocks[block_index].block_def.phi_r += alpha_r_dv.value
 
         return geometry
 
     @classmethod
-    def update_phi_r(cls, geometry, chromosome):
+    def update_phi_r(cls, geometry: Geometry, individual: Individual) -> Geometry:
         geometry = deepcopy(geometry)
-        for block_index_variable, value in chromosome.items():
-            if 'phi_r' in block_index_variable:
-                variable, layer_index, block_layer_index = block_index_variable.split(':')
-                layer_index = int(layer_index)
-                block_layer_index = int(block_layer_index)
+        phi_r_dvs = [block_dv for block_dv in individual.get_block_dvs() if block_dv.variable == 'phi_r']
+        for phi_r_dv in phi_r_dvs:
 
-                # block index
-                if block_layer_index <= len(geometry.layer_defs[layer_index - 1].blocks):
-                    no_block = geometry.layer_defs[layer_index - 1].blocks[block_layer_index - 1]
-                    block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
-                    geometry.blocks[block_index].block_def.phi_r = value
+            # block index
+            if phi_r_dv.block <= len(geometry.layer_defs[phi_r_dv.layer - 1].blocks):
+                no_block = geometry.layer_defs[phi_r_dv.layer - 1].blocks[phi_r_dv.block - 1]
+                block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
+                geometry.blocks[block_index].block_def.phi_r = phi_r_dv.value
 
         return geometry
 
@@ -220,24 +248,22 @@ class GeometryChange:
         return geometry
 
     @classmethod
-    def update_nco_r(cls, geometry, chromosome):
+    def update_nco_r(cls, geometry, individual: Individual):
+        block_dvs = individual.get_block_dvs()
+        nco_r_dvs = [block_dv for block_dv in block_dvs if block_dv.variable == 'nco_r']
         geometry = deepcopy(geometry)
-        for block_index_variable, value in chromosome.items():
-            if 'nco_r' in block_index_variable:
-                variable, layer_index, block_layer_index = block_index_variable.split(':')
-                layer_index = int(layer_index)
-                block_layer_index = int(block_layer_index)
 
-                # ToDo: this requires a correction in case the next one would receive some
-                no_block = geometry.layer_defs[layer_index - 1].blocks[block_layer_index - 1]
-                block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
-                block_def_curr = geometry.blocks[block_index].block_def
-                block_def_next = geometry.blocks[block_index + 1].block_def
-                if value >= 0:
-                    block_def_curr.nco += min(value, block_def_next.nco)
-                    block_def_next.nco -= min(value, block_def_next.nco)
-                else:
-                    block_def_curr.nco -= min(abs(value), block_def_curr.nco)
-                    block_def_next.nco += min(abs(value), block_def_next.nco)
+        for nco_r_dv in nco_r_dvs:
+            no_block = geometry.layer_defs[nco_r_dv.layer - 1].blocks[nco_r_dv.block - 1]
+            block_index = geometry.get_index_in_blocks_for_layer_block_index(no_block)
+            block_def_curr = geometry.blocks[block_index].block_def
+            block_def_next = geometry.blocks[block_index + 1].block_def
+            if nco_r_dv.value >= 0:
+                block_def_curr.nco += min(nco_r_dv.value, block_def_next.nco)
+                block_def_next.nco -= min(nco_r_dv.value, block_def_next.nco)
+            else:
+                block_def_curr.nco -= min(abs(nco_r_dv.value), block_def_curr.nco)
+                block_def_next.nco += min(abs(nco_r_dv.value), block_def_next.nco)
+
         geometry = GeometryChange.update_layer_indexing(geometry)
         return geometry
