@@ -168,8 +168,6 @@ class TerminalAnsysToolAdapter(AnsysToolAdapter):
         output_path = os.path.join(self.root_dir, self.input_folder_rel_dir, self.output_file)
         if os.path.isfile(output_path):
             os.remove(output_path)
-        else:  ## Show an error ##
-            print("Warning: %s file not found" % output_path)
 
         model_dir = os.path.join(self.root_dir, self.input_folder_rel_dir)
         input_path = os.path.join(self.root_dir, self.input_folder_rel_dir, self.input_file)
