@@ -58,15 +58,11 @@ class RoxieInputBuilder:
     harmonicoption = pd.DataFrame()
     graph = pd.DataFrame()
     graphoption = pd.DataFrame()
-    plot2d = pd.DataFrame([{'no': 1, 'zxaxis': 100, 'colour': 1, 'fquad': 1, 'harmcoil': 0, 'field': '|B|'},
-                           {'no': 1, 'zxaxis': 100, 'colour': 1, 'fquad': 1, 'harmcoil': 0, 'field': 'MARG'}])
+    plot2d = pd.DataFrame()
     plot2doption = pd.DataFrame()
     plot3d = pd.DataFrame()
     plot3doption = pd.DataFrame()
-    objective = pd.DataFrame([{'no': 1, 'string': 'B', 's1': 3, 's2': 1, 'oper': 7, 'constr': 0, 'weight': 0.1},
-                              {'no': 1, 'string': 'B', 's1': 5, 's2': 1, 'oper': 7, 'constr': 0, 'weight': 0.1},
-                              {'no': 1, 'string': 'MARGMI', 's1': 0, 's2': 0, 'oper': 12, 'constr': 15, 'weight': 1},
-                              {'no': 1, 'string': 'BIGB', 's1': 1, 's2': 1, 'oper': 12, 'constr': -15, 'weight': 2}])
+    objective = pd.DataFrame()
 
     def set_flag(self, flag_name: str, flag_value: bool) -> "RoxieInputBuilder":
         """ Method setting a flag in a ROXIE input file. An error is thrown if a flag does not exist
