@@ -10,11 +10,11 @@ from magnumapi.geometry.primitives.Line import Line
 from magnumapi.geometry.primitives.Point import Point
 from magnumapi.geometry.definitions.RelativeCosThetaBlockDefinition import RelativeCosThetaBlockDefinition
 from magnumapi.cadata.CableDatabase import CableDatabase
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class TestCosThetaBlock(TestCase):
-    cadata_file_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+    cadata_file_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
     cadata = CableDatabase.read_cadata(cadata_file_path)
 
     # BLOCK 1
