@@ -7,11 +7,11 @@ from magnumapi.geometry.primitives.Line import Line
 from magnumapi.geometry.blocks.RectangularBlock import RectangularBlock
 from magnumapi.geometry.definitions.RectangularBlockDefinition import RectangularBlockDefinition
 from magnumapi.cadata.CableDatabase import CableDatabase
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class TestRectangularBlock(TestCase):
-    cadata_file_path = create_resources_file_path('resources/geometry/roxie/SMC/roxie-SMC.cadata')
+    cadata_file_path = create_resources_path('resources/geometry/roxie/SMC/roxie-SMC.cadata')
     cadata = CableDatabase.read_cadata(cadata_file_path)
 
     # BLOCK 1
