@@ -4,7 +4,7 @@ from unittest.mock import patch
 from magnumapi.cadata.CableDatabase import CableDatabase
 from magnumapi.geometry.GeometryCheck import GeometryCheck
 from magnumapi.geometry.GeometryFactory import GeometryFactory
-from tests.resource_files import create_resources_file_path, read_csv_as_pd
+from tests.resource_files import create_resources_path, read_csv_as_pd
 
 
 class GeometryCheckTest(unittest.TestCase):
@@ -42,7 +42,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'type': 1,
                        'condname': '16TOL77B', 'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -60,8 +60,8 @@ class GeometryCheckTest(unittest.TestCase):
     @patch("matplotlib.pyplot.show")
     def test_check_geometry_consistency_first_quadrant_sm_ct_fail(self, mock_show=None):
         # arrange
-        json_path = create_resources_file_path('resources/geometry/roxie/SM_CT/SM_CT_rel.json')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        json_path = create_resources_path('resources/geometry/roxie/SM_CT/SM_CT_rel.json')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -81,7 +81,7 @@ class GeometryCheckTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_relative_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -105,7 +105,7 @@ class GeometryCheckTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_relative_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -152,7 +152,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -195,7 +195,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -238,7 +238,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -281,7 +281,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -324,7 +324,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -367,7 +367,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -410,7 +410,7 @@ class GeometryCheckTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'condname': '16TOL77B',
                        'current': 13500, 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0, 'type': 1}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
