@@ -8,7 +8,7 @@ from magnumapi.geometry.GeometryFactory import GeometryFactory
 from magnumapi.geometry.GeometryPlot import GeometryPlot
 from magnumapi.geometry.primitives.Line import Line
 from magnumapi.cadata.CableDatabase import CableDatabase
-from tests.resource_files import read_csv_as_pd, create_resources_file_path
+from tests.resource_files import read_csv_as_pd, create_resources_path
 
 
 class CosThetaGeometryTest(unittest.TestCase):
@@ -47,7 +47,7 @@ class CosThetaGeometryTest(unittest.TestCase):
             {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'type': 1, 'current': 13500,
              'condname': '16TOL77B', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -91,7 +91,7 @@ class CosThetaGeometryTest(unittest.TestCase):
             {'no': 12, 'radius': 67.45, 'alpha': 30, 'phi': 37.9, 'nco': 11, 'type': 1, 'current': 13500,
              'condname': '16TOL77B', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -135,7 +135,7 @@ class CosThetaGeometryTest(unittest.TestCase):
             {'no': 12, 'radius': 67.45, 'alpha_r': 30, 'phi_r': 4.76003, 'nco': 11, 'type': 1, 'current': 13500,
              'condname': '16TOL77B', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -183,7 +183,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha_r': 9.84375, 'phi_r': 6.71875, 'nco': 12, 'type': 1,
                        'current': 13500, 'condname': '16TOL77B', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -199,9 +199,9 @@ class CosThetaGeometryTest(unittest.TestCase):
     def test_build_geometry_with_roxie_bare_absolute_angles_rectangle_csv(self, mock_show=None):
         # arrange
         root_dir = 'resources/geometry/roxie/16T/'
-        block_df_path = create_resources_file_path('%sbare_absolute_block_data_rectangle.csv' % root_dir)
-        layer_df_path = create_resources_file_path('%slayer_data.csv' % root_dir)
-        cadata_path = create_resources_file_path('%sroxieold_2.cadata' % root_dir)
+        block_df_path = create_resources_path('%sbare_absolute_block_data_rectangle.csv' % root_dir)
+        layer_df_path = create_resources_path('%slayer_data.csv' % root_dir)
+        cadata_path = create_resources_path('%sroxieold_2.cadata' % root_dir)
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -222,7 +222,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/bare_absolute_block_data_rectangle.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -242,9 +242,9 @@ class CosThetaGeometryTest(unittest.TestCase):
     def test_build_geometry_with_roxie_bare_relative_angles_rectangle_csv(self, mock_show=None):
         # arrange
         root_dir = 'resources/geometry/roxie/16T/'
-        block_df_path = create_resources_file_path('%sbare_relative_block_data_rectangle.csv' % root_dir)
-        layer_df_path = create_resources_file_path('%slayer_data.csv' % root_dir)
-        cadata_path = create_resources_file_path('%sroxieold_2.cadata' % root_dir)
+        block_df_path = create_resources_path('%sbare_relative_block_data_rectangle.csv' % root_dir)
+        layer_df_path = create_resources_path('%slayer_data.csv' % root_dir)
+        cadata_path = create_resources_path('%sroxieold_2.cadata' % root_dir)
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -265,7 +265,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/bare_relative_block_data_rectangle.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -284,8 +284,8 @@ class CosThetaGeometryTest(unittest.TestCase):
     @patch("matplotlib.pyplot.show")
     def test_build_geometry_with_roxie_bare_absolute_angles_rectangle_data(self, mock_show=None):
         # arrange
-        data_path = create_resources_file_path('resources/geometry/roxie/16T/16T_22b-37-optd7f8_gx.data')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        data_path = create_resources_path('resources/geometry/roxie/16T/16T_22b-37-optd7f8_gx.data')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -302,7 +302,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/bare_absolute_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -323,7 +323,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrangee
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/bare_relative_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -344,7 +344,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_relative_block_data_rectangle.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -365,7 +365,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_absolute_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -386,7 +386,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_relative_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -408,7 +408,7 @@ class CosThetaGeometryTest(unittest.TestCase):
         # arrange
         block_df = read_csv_as_pd('resources/geometry/roxie/16T/ins_relative_block_data_trapezoid.csv')
         layer_df = read_csv_as_pd('resources/geometry/roxie/16T/layer_data.csv')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -447,7 +447,7 @@ class CosThetaGeometryTest(unittest.TestCase):
              'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1, "symm": 1, "typexy": 1, "blocks": [1]}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -585,7 +585,7 @@ class CosThetaGeometryTest(unittest.TestCase):
              'condname': '16TOL78B', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1, "symm": 1, "typexy": 1, "blocks": [1]}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -740,7 +740,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                       {'no': 12, 'radius': 67.45, 'alpha_r': 0.15625, 'phi_r': 3.0, 'nco': 12, 'type': 1,
                        'current': 13500, 'condname': '16TOL8', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -789,7 +789,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                        'type': 1,
                        'current': 13500, 'condname': '16TOL8', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -813,7 +813,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                       'condname': '16TIL9', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1, "symm": 1, "typexy": 1, "blocks": [1]}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -832,7 +832,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                       'condname': '16TIL9', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1, "symm": 1, "typexy": 1, "blocks": [1]}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -853,7 +853,7 @@ class CosThetaGeometryTest(unittest.TestCase):
                       'condname': '16TIL9', 'n1': 2, 'n2': 20, 'imag': 0, 'turn': 0}]
         layer_def = [{"no": 1, "symm": 1, "typexy": 1, "blocks": [1]}]
 
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -863,8 +863,8 @@ class CosThetaGeometryTest(unittest.TestCase):
 
     def test_with_roxie_absolute_angle_definition_json(self):
         # arrange
-        json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_abs.json')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        json_path = create_resources_path('resources/geometry/roxie/16T/16T_abs.json')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -887,8 +887,8 @@ class CosThetaGeometryTest(unittest.TestCase):
 
     def test_with_roxie_relative_angle_definition_json(self):
         # arrange
-        json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_rel.json')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        json_path = create_resources_path('resources/geometry/roxie/16T/16T_rel.json')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
@@ -912,8 +912,8 @@ class CosThetaGeometryTest(unittest.TestCase):
     @patch("plotly.graph_objects.Figure.show")
     def test_with_roxie_absolute_angle_definition_json_radiality_corection(self, mock_show=None):
         # arrange
-        json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_abs.json')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        json_path = create_resources_path('resources/geometry/roxie/16T/16T_abs.json')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
 
         # act
