@@ -3,7 +3,7 @@ import unittest
 import numpy as np
 
 from magnumapi.matpro.heat_capacities import calc_cv_cu_nist, calc_cv_nb3sn_nist
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class Test_heat_capacities(unittest.TestCase):
@@ -16,7 +16,7 @@ class Test_heat_capacities(unittest.TestCase):
         cv_cu_nist = calc_cv_cu_nist(T)
 
         # assert
-        path = create_resources_file_path('resources/matpro/heat_capacities/cv_cu_nist.txt')
+        path = create_resources_path('resources/matpro/heat_capacities/cv_cu_nist.txt')
         cv_cu_nist_ref = np.loadtxt(path)
         np.testing.assert_allclose(cv_cu_nist_ref, cv_cu_nist)
 
@@ -29,7 +29,7 @@ class Test_heat_capacities(unittest.TestCase):
         cv_nb3sn_nist = calc_cv_nb3sn_nist(T, B=5.0)
 
         # assert
-        path = create_resources_file_path('resources/matpro/heat_capacities/cv_nb3sn_nist.txt')
+        path = create_resources_path('resources/matpro/heat_capacities/cv_nb3sn_nist.txt')
         cv_nb3sn_nist_ref = np.loadtxt(path)
         np.testing.assert_allclose(cv_nb3sn_nist_ref, cv_nb3sn_nist)
 
