@@ -3,7 +3,7 @@ import unittest
 import numpy as np
 
 from magnumapi.matpro.resistivities import calc_rho_cu_nist
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class Test_heat_capacities(unittest.TestCase):
@@ -16,7 +16,7 @@ class Test_heat_capacities(unittest.TestCase):
         rho_cu_nist = calc_rho_cu_nist(T, B=5, RRR=100)
 
         # assert
-        path = create_resources_file_path('resources/matpro/resistivities/rho_cu_nist.txt')
+        path = create_resources_path('resources/matpro/resistivities/rho_cu_nist.txt')
         rho_cu_nist_ref = np.loadtxt(path)
         np.testing.assert_allclose(rho_cu_nist_ref, rho_cu_nist)
 
