@@ -5,7 +5,7 @@ import pytest
 
 from magnumapi.tool_adapters.ansys.AnsysToolAdapter import AnsysToolAdapter
 from magnumapi.tool_adapters.roxie.RoxieToolAdapter import RoxieToolAdapter
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 config = {"input_folder_rel_dir": "input%sMechanic_Plate" % os.sep,
           "input_file": "15T_mech.inp",
@@ -51,9 +51,9 @@ class TestAnsysToolAdapter(unittest.TestCase):
 
     def test_convert_roxie_force_file_to_ansys(self):
         # arrange
-        roxie_force_input_path = create_resources_file_path('resources/tool_adapters/ansys/roxie.force2d')
-        roxie_force_output_path = create_resources_file_path('resources/tool_adapters/ansys/roxie_edit.force2d')
-        ansys_force_output_path = create_resources_file_path('resources/tool_adapters/ansys/forces_edit.vallone')
+        roxie_force_input_path = create_resources_path('resources/tool_adapters/ansys/roxie.force2d')
+        roxie_force_output_path = create_resources_path('resources/tool_adapters/ansys/roxie_edit.force2d')
+        ansys_force_output_path = create_resources_path('resources/tool_adapters/ansys/forces_edit.vallone')
         field = 16
         target_field = 15
 
@@ -71,7 +71,7 @@ class TestAnsysToolAdapter(unittest.TestCase):
         with open(ansys_force_output_path, 'r') as file:
             ansys_force = file.readlines()
 
-        output_text_ref_path = create_resources_file_path('resources/tool_adapters/ansys/forces_edit_ref.vallone')
+        output_text_ref_path = create_resources_path('resources/tool_adapters/ansys/forces_edit_ref.vallone')
 
         with open(output_text_ref_path, 'r') as file:
             ansys_force_ref = file.readlines()
