@@ -1,9 +1,11 @@
 from unittest import TestCase
 
+import pandas as pd
+
 from magnumapi.geometry.GeometryFactory import GeometryFactory
 from magnumapi.cadata.CableDatabase import CableDatabase
 from magnumapi.tool_adapters.roxie.RoxieInputBuilder import RoxieInputBuilder
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class TestRoxieInputBuilder(TestCase):
@@ -34,8 +36,8 @@ class TestRoxieInputBuilder(TestCase):
     def test_build(self):
         self.maxDiff = None
         # arrange
-        json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_abs.json')
-        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        json_path = create_resources_path('resources/geometry/roxie/16T/16T_abs.json')
+        cadata_path = create_resources_path('resources/geometry/roxie/16T/roxieold_2.cadata')
         cadata = CableDatabase.read_cadata(cadata_path)
         roxie_input = RoxieInputBuilder()
         geometry = GeometryFactory.init_with_json(json_path, cadata)
@@ -43,12 +45,20 @@ class TestRoxieInputBuilder(TestCase):
         # act
         roxie_input.block = geometry.to_block_df()
         roxie_input.layer = geometry.to_layer_df()
+        roxie_input.plot2d = pd.DataFrame(
+            [{'no': 1, 'zxaxis': 100, 'colour': 1, 'fquad': 1, 'harmcoil': 0, 'field': '|B|'},
+             {'no': 1, 'zxaxis': 100, 'colour': 1, 'fquad': 1, 'harmcoil': 1, 'field': 'B3'}])
+        roxie_input.objective = pd.DataFrame(
+            [{'no': 1, 'string': 'B', 's1': 3, 's2': 1, 'oper': 7, 'constr': 0, 'weight': 0.1},
+             {'no': 1, 'string': 'B', 's1': 5, 's2': 1, 'oper': 7, 'constr': 0, 'weight': 0.1},
+             {'no': 1, 'string': 'MARGMI', 's1': 0, 's2': 0, 'oper': 12, 'constr': 15, 'weight': 1},
+             {'no': 1, 'string': 'BIGB', 's1': 1, 's2': 1, 'oper': 12, 'constr': -15, 'weight': 2}])
 
         # assert
-        data_path = create_resources_file_path('resources/geometry/roxie/16T/16T_abs.data')
+        data_path = create_resources_path('resources/geometry/roxie/16T/16T_abs.data')
         roxie_input.build(data_path)
 
-        data_path_ref = create_resources_file_path('resources/geometry/roxie/16T/reference/16T_abs_ref.data')
+        data_path_ref = create_resources_path('resources/geometry/roxie/16T/reference/16T_abs_ref.data')
 
         with open(data_path, 'r') as file:
             file_str = file.read()
