@@ -1,7 +1,7 @@
 import unittest
 
 import magnumapi.tool_adapters.roxie.RoxieAPI as RoxieAPI
-from tests.resource_files import create_resources_file_path
+from tests.resource_files import create_resources_path
 
 
 class TestRoxieAPI(unittest.TestCase):
@@ -18,7 +18,7 @@ class TestRoxieAPI(unittest.TestCase):
 
     def test_read_nested_bottom_header_table(self):
         # arrange
-        data_path = create_resources_file_path('resources/geometry/roxie/16T/16T_22b-37-optd7f8_gx.data')
+        data_path = create_resources_path('resources/geometry/roxie/16T/16T_22b-37-optd7f8_gx.data')
 
         # act
         layer_defs_df = RoxieAPI.read_nested_bottom_header_table(data_path, keyword='LAYER')
